def black():

    cor = 0x00000

    return cor

def grey11():

    cor = 0x1C1C1C

    return cor

def grey21():

    cor = 0x363636

    return cor

def grey31():

    cor = 0x4F4F4F

    return cor

def dimgray():

    cor = 0x696969

    return cor

def gray():

    cor = 0x808080

    return cor

def darkgray():

    cor = 0xA9A9A9

    return cor

def silver():

    cor = 0xC0C0C0

    return cor

def ligthgrey():

    cor = 0xD3D3D3

    return cor

def gainsboro():

    cor = 0xDCDCDC

    return cor


def cyan():

    cor = 0x00FFFF

    return cor

def darkturquoise():

    cor = 0x00CED1

    return cor

def turquoise():

    cor = 0x40E0D0

    return cor

def mediumturquoise():

    cor = 0x48D1CC

    return cor

def lightseagreen():

    cor = 0x20B2AA

    return cor

def darkcyan():

    cor = 0x008B8B

    return cor

def teal():

    cor = 0x008080

    return cor

def aquamarine():

    cor = 0x7FFFD4

    return cor

def mediumaquamarine():

    cor = 0x66CDAA

    return cor

def cadetblue():

    cor = 0x5F9EA0

    return cor


def maroon():

    cor = 0x800000

    return cor

def darkred():

    cor = 0x8B0000

    return cor

def firebrick():

    cor = 0xB22222

    return cor

def brown():

    cor = 0xA52A2A

    return cor

def salmon():

    cor = 0xFA8072

    return cor

def darksalmon():

    cor = 0xE9967A

    return cor

def lightsalmon():

    cor = 0xFFA07A

    return cor

def coral():

    cor = 0xFF7F50

    return cor

def tomato():

    cor = 0xFF6347

    return cor

def red():

    cor = 0xFF0000

    return cor


from setuptools import setup

with open("README.md", "r") as f:

    long_description = f.read()

setup(
    name="hexacolors",
    version="0.3.5",
    url = 'https://github.com/Marciel404/hexacolors',
    author="Marciel404",
    description="Convert string color for hexadecimal understandable by python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=["hexacolors","hexacolors.colors"],
    license = 'MIT',
    keywords = 'String to hexadecimal color converter' ,
    CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Internet',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    ],
    python_requires='>=3.8',
    install_requires=['requests>=2.28.1'],
    dependency_links=['https://github.com/Marciel404/hexacolors']
)


"""
hexacolors
~~~~~~~~~~~~~~~~~~~

A simple library that converts string to hexadecimal understandable by python

:(c) 2022-present Marciel404
:license: MIT, see LICENSE for more details.
"""

__title__ = "Hexacolors"
__author__ = "Marciel404"
__license__ = "MIT"
__copyright__ = "2022-present Marciel404"
__version__ = "0.3.5"

__path__ = __import__("pkgutil").extend_path(__path__, __name__)

from .convertingcolor import hexacolor, stringcolor
from .listcolors import (
    listblack,
    listblue,
    listcyan,
    listgreen,
    listbrown,
    listpurple,
    listpink,
    listred,
    listorange,
    listyellow,
    listlight,
    listall
    )


def white():

    cor = 0xFFFFFF

    return cor

def aliceblue():

    cor = 0xF0F8FF

    return cor

def ghostwhite():

    cor = 0xF8F8FF

    return cor

def snow():

    cor = 0xFFFAFA

    return cor

def seashell():

    cor = 0xFFF5EE

    return cor

def floralwhite():

    cor = 0xFFFAF0

    return cor

def whitesmoke():

    cor = 0xF5F5F5

    return cor

def beige():

    cor = 0xF5F5DC

    return cor

def oldlace():

    cor = 0xFDF5E6

    return cor

def ivory():

    cor = 0xFFFFF0

    return cor

def linen():

    cor = 0xFAF0E6

    return cor

def cornsilk():

    cor = 0xFFF8DC

    return cor

def antiquewhite():

    cor = 0xFAEBD7

    return cor

def blanchedalmond():

    cor = 0xFFEBCD

    return cor

def bisque():

    cor = 0xFFE4C4

    return cor

def lightyellow():

    cor = 0xFFFFE0

    return cor

def lemonchiffon():

    cor = 0xFFFACD

    return cor

def lightgoldenrodyellow():

    cor = 0xFAFAD2

    return cor

def papayawhip():

    cor = 0xFFEFD5

    return cor

def peachpuff():

    cor = 0xFFDAB9

    return cor

def moccasin():

    cor = 0xFFE4B5

    return cor

def palegoldenrod():

    cor = 0xEEE8AA

    return cor

def mistyrose():

    cor = 0xFFE4E1

    return cor

def lavenderblush():

    cor = 0xFFF0F5

    return cor

def lavender():

    cor = 0xE6E6FA

    return cor

def thistle():

    cor = 0xD8BFD8

    return cor

def azure():

    cor = 0xF0FFFF

    return cor

def lightcyan():

    cor = 0xE0FFFF

    return cor

def powderblue():

    cor = 0xB0E0E6

    return cor

def paleturquoise():

    cor = 0xE0FFFF

    return cor

def honeydew():

    cor = 0xF0FFF0

    return cor

def mintcream():

    cor = 0xF5FFFA

    return cor